summaryrefslogtreecommitdiffstats
path: root/src/kile/tabulardialog.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'src/kile/tabulardialog.cpp')
-rw-r--r--src/kile/tabulardialog.cpp62
1 files changed, 31 insertions, 31 deletions
diff --git a/src/kile/tabulardialog.cpp b/src/kile/tabulardialog.cpp
index 27a936c..364de37 100644
--- a/src/kile/tabulardialog.cpp
+++ b/src/kile/tabulardialog.cpp
@@ -290,7 +290,7 @@ TabCellDialog::TabCellDialog(TQWidget *parent, TabularCell::Data *data,
colorgrouptqlayout->addWidget( m_ccBgcolor,0,1 );
colorgrouptqlayout->addWidget( m_ccTextcolor,1,1 );
- // tqalignment group
+ // alignment group
TQButtonGroup *aligngroup = new TQButtonGroup( i18n("Alignment"),page);
aligngroup->setColumnLayout(0, Qt::Vertical );
aligngroup->tqlayout()->setSpacing( 6 );
@@ -442,9 +442,9 @@ TabCellDialog::TabCellDialog(TQWidget *parent, TabularCell::Data *data,
connect(m_cbSep,TQT_SIGNAL(clicked()),this, TQT_SLOT(slotSeparatorClicked()));
}
- TQWhatsThis::add(m_coHeader,i18n("Column or cell tqalignment."));
+ TQWhatsThis::add(m_coHeader,i18n("Column or cell alignment."));
TQWhatsThis::add(m_cbBold,i18n("Set bold font series."));
- TQWhatsThis::add(m_cbItalic,i18n("Set italic font tqshape."));
+ TQWhatsThis::add(m_cbItalic,i18n("Set italic font shape."));
TQWhatsThis::add(m_rbAlignleft,i18n("The text will be aligned at the left border of the cell."));
TQWhatsThis::add(m_rbAligncenter,i18n("The text will be centered."));
TQWhatsThis::add(m_rbAlignright,i18n("The text will be aligned at the right border of the cell."));
@@ -460,7 +460,7 @@ TabCellDialog::TabCellDialog(TQWidget *parent, TabularCell::Data *data,
TQWhatsThis::add(m_pbFrame4,i18n("Set all border lines."));
TQWhatsThis::add(m_cellframe,i18n("Set user defined border lines. A mouse click into one of the four border ranges will set or clear this special border line."));
- setButtonWhatsThis(User1,i18n("Reset all settings to standard cell attributes: left tqalignment, normal font series and tqshape, white background color, black text color, no border lines."));
+ setButtonWhatsThis(User1,i18n("Reset all settings to standard cell attributes: left alignment, normal font series and shape, white background color, black text color, no border lines."));
}
////////////////////////////// read data //////////////////////////////
@@ -634,7 +634,7 @@ TabularItem::TabularItem(TQTable* table, const TabularCell::Data &data)
m_data = data;
}
-int TabularItem::tqalignment() const
+int TabularItem::alignment() const
{
return m_data.align | TQt::AlignVCenter;
}
@@ -668,7 +668,7 @@ void TabularItem::paint(TQPainter *p,const TQColorGroup &cg,const TQRect &cr,boo
p->setFont(f);
}
- p->drawText( 2,0,w-4,h,tqalignment(), text() );
+ p->drawText( 2,0,w-4,h,alignment(), text() );
}
//END TabularItem
@@ -1119,7 +1119,7 @@ TQPopupMenu *TabularTable::createPopupMenu()
void TabularTable::insertPopupAlign(TQPopupMenu *popup,bool header)
{
- // tqalignment
+ // alignment
int align = 0;
//calculate
@@ -2137,13 +2137,13 @@ TQStringList TabularDialog::sortColorTable(TQMap<TQString,char> &colors)
sred = convertColor(r);
sgreen = convertColor(g);
sblue = convertColor(b);
- s = TQString("{rgb}{%1,%2,%3}").tqarg(sred).tqarg(sgreen).tqarg(sblue);
+ s = TQString("{rgb}{%1,%2,%3}").arg(sred).arg(sgreen).arg(sblue);
}
else
{
- s = TQString("{gray}{%1}").tqarg(convertColor(r));
+ s = TQString("{gray}{%1}").arg(convertColor(r));
}
- list << TQString("\\definecolor{tc%1}%2").tqarg(it.data()).tqarg(s);
+ list << TQString("\\definecolor{tc%1}%2").arg(it.data()).arg(s);
}
list.sort();
@@ -2236,21 +2236,21 @@ void TabularDialog::slotOk()
if ( colinfo[col].bgcolor != whitename )
{
TQChar color = defineColor(colinfo[col].bgcolor,colortable,colorchar);
- colorcommand += TQString("\\columncolor{tc%1}").tqarg(color);
+ colorcommand += TQString("\\columncolor{tc%1}").arg(color);
pkgColortbl = true;
}
if ( colinfo[col].textcolor != blackname )
{
TQChar color = defineColor(colinfo[col].textcolor,colortable,colorchar);
- colorcommand += TQString("\\color{tc%1}").tqarg(color);
+ colorcommand += TQString("\\color{tc%1}").arg(color);
pkgColor = true;
}
if ( ! colorcommand.isEmpty() )
{
if ( s.find('>') >= 0 )
- s = s.replace(">{}",TQString(">{%1}").tqarg(colorcommand));
+ s = s.replace(">{}",TQString(">{%1}").arg(colorcommand));
else
- preamble += TQString(">{%1}").tqarg(colorcommand);
+ preamble += TQString(">{%1}").arg(colorcommand);
pkgArray = true;
}
@@ -2285,7 +2285,7 @@ void TabularDialog::slotOk()
if ( bgcolor != whitename )
{
TQChar color = defineColor(cnt.nameBgcolor,colortable,colorchar);
- textline += TQString("\\rowcolor{tc%1}\n").tqarg(color);
+ textline += TQString("\\rowcolor{tc%1}\n").arg(color);
pkgColortbl = true;
}
@@ -2297,11 +2297,11 @@ void TabularDialog::slotOk()
{
// check for multicolumn and initialize string parameter
int colspan = cellitem->colSpan();
- s1 = ( colspan > 1 ) ? TQString("%1").tqarg(colspan) : TQString();
+ s1 = ( colspan > 1 ) ? TQString("%1").arg(colspan) : TQString();
s2 = s3 = TQString();
// Now look, if this cell(s) must be defined as multicolumn, because
// colspan is greater than 1, or the left vline, bgcolor or tqalignment
// is different from the preamble
bool useMulticolumn =
( ( colspan > 1 ) ||
@@ -2325,10 +2325,10 @@ void TabularDialog::slotOk()
if ( cellitem->m_data.bgcolor.name() != whitename )
{
TQChar color = defineColor(cellitem->m_data.bgcolor.name(),colortable,colorchar);
- s2 += TQString(">{\\columncolor{tc%1}}").tqarg(color);
+ s2 += TQString(">{\\columncolor{tc%1}}").arg(color);
pkgColortbl = true;
}
- // tqalignment
+ // alignment
//if ( cellitem->m_data.align!=colinfo[col].align ) {
switch ( cellitem->m_data.align )
{
@@ -2350,13 +2350,13 @@ void TabularDialog::slotOk()
}
if ( colinfo[col].italic != (cellitem->m_data.font & TabularCell::cfItalic) )
{
- s3 += "\\ittqshape";
+ s3 += "\\itshape";
}
if ( colinfo[col].textcolor != cellitem->m_data.textcolor.name() )
{
TQChar color = defineColor(cellitem->m_data.textcolor.name(),colortable,colorchar);
- s3 += TQString("\\color{tc%1}").tqarg(color);
+ s3 += TQString("\\color{tc%1}").arg(color);
pkgColor = true;
}
if ( ! s3.isEmpty() )
@@ -2379,7 +2379,7 @@ void TabularDialog::slotOk()
// build the whole cell entry
if ( useMulticolumn )
{
- textline += TQString("\\mc{%1}{%2}{%3}").tqarg(colspan).tqarg(s2).tqarg(s3);
+ textline += TQString("\\mc{%1}{%2}{%3}").arg(colspan).arg(s2).arg(s3);
multicolumn = true;
}
else
@@ -2445,7 +2445,7 @@ void TabularDialog::slotOk()
// build the tag to insert
if ( m_cbCenter->isChecked() )
- m_td.tagBegin = TQString("\\begin{%1}\n").tqarg(centername);
+ m_td.tagBegin = TQString("\\begin{%1}\n").arg(centername);
else if ( group )
m_td.tagBegin = "{% \n";
else
@@ -2468,22 +2468,22 @@ void TabularDialog::slotOk()
}
// add environment command
- m_td.tagBegin += TQString("\\begin{%1}").tqarg(envname);
+ m_td.tagBegin += TQString("\\begin{%1}").arg(envname);
// add width for starred versions
if ( m_cbStarred->isChecked() )
- m_td.tagBegin += TQString("{%1}").tqarg(bullet);
- // add optional tqalignment parameter
+ m_td.tagBegin += TQString("{%1}").arg(bullet);
+ // add optional alignment parameter
TQString envparameter = ( m_coParameter->isEnabled() ) ? m_coParameter->currentText() : TQString();
if ( ! envparameter.isEmpty() )
- m_td.tagBegin += TQString("[%1]").tqarg(envparameter);
+ m_td.tagBegin += TQString("[%1]").arg(envparameter);
// add preamble
- m_td.tagBegin += TQString("{%1}").tqarg(preamble);
+ m_td.tagBegin += TQString("{%1}").arg(preamble);
m_td.tagBegin += getEol(0,true) + '\n';
// close environment
- m_td.tagEnd += TQString("\\end{%1}\n").tqarg(envname);
+ m_td.tagEnd += TQString("\\end{%1}\n").arg(envname);
if ( m_cbCenter->isChecked() )
- m_td.tagEnd += TQString("\\end{%1}\n").tqarg(centername);
+ m_td.tagEnd += TQString("\\end{%1}\n").arg(centername);
else if ( group )
m_td.tagEnd += "}\n";
@@ -2543,7 +2543,7 @@ TQString TabularDialog::getEol(int row, bool top)
{
TQString cmd = ( booktabs ) ? "cmidrule" : "cline";
for ( uint i=0; i<lines.list.count(); i+=2 )
- s += TQString("\\%1{%2-%3}").tqarg(cmd).tqarg(lines.list[i]+1).tqarg(lines.list[i+1]+1);
+ s += TQString("\\%1{%2-%3}").arg(cmd).arg(lines.list[i]+1).arg(lines.list[i+1]+1);
}
return s;
@@ -2297,11 +2297,11 @@ void TabularDialog::slotOk()
s2 = s3 = TQString();
// Now look, if this cell(s) must be defined as multicolumn, because
- // colspan is greater than 1, or the left vline, bgcolor or tqalignment
+ // colspan is greater than 1, or the left vline, bgcolor or alignment
// is different from the preamble
bool useMulticolumn =